@@ -1,32 +1,42 @@
 import os
 import shutil
 import sys
+from multiprocessing.context import Process
 from pathlib import Path
 
 import yaml
-from markdownup.config import extend_default_config
+from markdownup.cache_application import CacheApplication
+from markdownup.config import Config, default_config
 from markdownup.wsgi_application import WsgiApplication
 
 
 def _main():
 
     if len(sys.argv) == 2:
+
+        # initialize config based on argv
+        config = None
         as_path = Path(sys.argv[1])
         if as_path.is_dir():
-            config = extend_default_config({'content': {'root': sys.argv[1]}})
-            WsgiApplication(config).run()
-            exit(0)
+            config = Config.from_dict({'content': {'root': sys.argv[1]}})
         elif as_path.is_file():
-            config = yaml.load(as_path.read_text(), yaml.FullLoader)
-            config = extend_default_config(config)
             os.chdir(as_path.parent)  # pretend to run from the config's parent dir
+            config = Config.from_file(as_path)
+
+        if config:
+
+            # launch a new process for the built in cache server which is a bit crude but suffices for now
+            Process(target=CacheApplication(config).run).start()
+
+            # launch the main MarkdownUp WSGI application
             WsgiApplication(config).run()
+
+            # if the above returns we exit normally
             exit(0)
 
     if len(sys.argv) > 2:
         if sys.argv[1] == '--start-config':
-            config = extend_default_config({'content': {'root': '.'}})
-            config = yaml.dump(config)
+            config = yaml.dump(default_config)
             with open(sys.argv[2], 'w') as file:
                 file.write(config)
             exit(0)
